==> ruby-bunny_1.1.2.orig.tar.gz: bunny-1.1.2/spec/unit/concurrent/synchronized_sorted_set_spec.rb <==
require "spec_helper"
require "bunny/concurrent/synchronized_sorted_set"

unless ENV["CI"]
  describe Bunny::Concurrent::SynchronizedSortedSet do
    50.times do |i|
      it "provides the same API as SortedSet for key operations (take #{i})" do
        s = described_class.new
        s.length.should == 0

        s << 1
        s.length.should == 1
        s << 1
        s.length.should == 1
        s << 2
        s.length.should == 2
        s << 3
        s.length.should == 3
        s << 4
        s.length.should == 4
        s << 4
        s << 4
        s << 4
        s.length.should == 4
        s << 5
        s.length.should == 5
        s << 5
        s << 5
        s << 5
        s.length.should == 5
        s << 6
        s.length.should == 6
        s << 7
        s.length.should == 7
        s << 8
        s.length.should == 8
        s.delete 8
        s.length.should == 7
        s.delete_if { |i| i == 1 }
        s.length.should == 6
      end
      it "synchronizes common operations needed by Bunny (take #{i})" do
        s = described_class.new
        s.length.should == 0

        10.times do
          Thread.new do
            s << 1
            s << 1
            s << 2
            s << 3
            s << 4
            s << 4
            s << 4
            s << 4
            s << 5
            s << 5
            s << 5
            s << 5
            s << 6
            s << 7
            s << 8
            s.delete 8
            s.delete_if { |i| i == 1 }
          end
        end
        sleep 0.5

        s.length.should == 6
      end
    end
  end
end

==> ruby-bunny_2.19.0.orig.tar.gz: bunny-2.19.0/spec/unit/concurrent/synchronized_sorted_set_spec.rb <==
require "spec_helper"
require "bunny/concurrent/synchronized_sorted_set"

unless ENV["CI"]
  describe Bunny::Concurrent::SynchronizedSortedSet do
    50.times do |i|
      it "provides the same API as SortedSet for key operations (take #{i})" do
        s = described_class.new
        expect(s.length).to eq 0

        s << 1
        expect(s.length).to eq 1
        s << 1
        expect(s.length).to eq 1
        s << 2
        expect(s.length).to eq 2
        s << 3
        expect(s.length).to eq 3
        s << 4
        expect(s.length).to eq 4
        s << 4
        s << 4
        s << 4
        expect(s.length).to eq 4
        s << 5
        expect(s.length).to eq 5
        s << 5
        s << 5
        s << 5
        expect(s.length).to eq 5
        s << 6
        expect(s.length).to eq 6
        s << 7
        expect(s.length).to eq 7
        s << 8
        expect(s.length).to eq 8
        s.delete 8
        expect(s.length).to eq 7
        s.delete_if { |i| i == 1 }
        expect(s.length).to eq 6
      end
      it "synchronizes common operations needed by Bunny (take #{i})" do
        s = described_class.new
        expect(s.length).to eq 0

        10.times do
          Thread.new do
            s << 1
            s << 1
            s << 2
            s << 3
            s << 4
            s << 4
            s << 4
            s << 4
            s << 5
            s << 5
            s << 5
            s << 5
            s << 6
            s << 7
            s << 8
            s.delete 8
            s.delete_if { |i| i == 1 }
          end
        end
        sleep 0.5

        expect(s.length).to eq 6
      end
    end
  end
end
